powered by
This function retrieves multiple Finna records based on a vector of record IDs. You can specify which fields to return, the language, and the pagination options.
get_finna_records( ids, field = NULL, prettyPrint = FALSE, lng = "fi", page = 1, limit = 100 )
A tibble containing the retrieved records data with provenance information.
A vector of record IDs to retrieve.
A vector of fields to return. Defaults to NULL, which returns all default fields.
Logical; whether to pretty-print the response. Defaults to FALSE.
Language for returned translated strings. Defaults to "fi".
The page number to retrieve. Defaults to 1.
The number of records to return per page. Defaults to 20.
records <- get_finna_records("fikka.3405646", field = "title", prettyPrint = TRUE, lng = "en-gb") print(records)
Run the code above in your browser using DataLab