powered by
This function retrieves only the publisher information from the Finna index based on the search query.
search_publisher( query = NULL, limit = 100, lng = "fi", filters = NULL, prettyPrint = FALSE )
A tibble containing the record IDs and their respective publishers.
A string specifying the search query.
An integer specifying the total number of records to return.
A string for the language of returned translated strings. Defaults to "fi".
A vector of filter queries to refine the search. Defaults to NULL.
A logical value indicating whether to pretty-print the JSON response. Defaults to FALSE.
publishers <- search_publisher("sibelius", limit = 10) print(publishers)
Run the code above in your browser using DataLab